@@ -26,6 +26,12 @@ from ...models.bulk_update_dna_sequences_async_task import BulkUpdateDnaSequence
 from ...models.bulk_update_rna_oligos_async_task import BulkUpdateRnaOligosAsyncTask
 from ...models.bulk_update_rna_sequences_async_task import BulkUpdateRnaSequencesAsyncTask
 from ...models.create_consensus_alignment_async_task import CreateConsensusAlignmentAsyncTask
+from ...models.create_nucleotide_consensus_alignment_async_task import (
+    CreateNucleotideConsensusAlignmentAsyncTask,
+)
+from ...models.create_nucleotide_template_alignment_async_task import (
+    CreateNucleotideTemplateAlignmentAsyncTask,
+)
 from ...models.create_template_alignment_async_task import CreateTemplateAlignmentAsyncTask
 from ...models.exports_async_task import ExportsAsyncTask
 from ...models.find_matching_regions_async_task import FindMatchingRegionsAsyncTask
@@ -63,6 +69,8 @@ def _parse_response(
             AsyncTask,
             CreateTemplateAlignmentAsyncTask,
             CreateConsensusAlignmentAsyncTask,
+            CreateNucleotideTemplateAlignmentAsyncTask,
+            CreateNucleotideConsensusAlignmentAsyncTask,
             BulkCreateDnaSequencesAsyncTask,
             BulkUpdateDnaSequencesAsyncTask,
             BulkCreateRnaSequencesAsyncTask,
@@ -99,6 +107,8 @@ def _parse_response(
             AsyncTask,
             CreateTemplateAlignmentAsyncTask,
             CreateConsensusAlignmentAsyncTask,
+            CreateNucleotideTemplateAlignmentAsyncTask,
+            CreateNucleotideConsensusAlignmentAsyncTask,
             BulkCreateDnaSequencesAsyncTask,
             BulkUpdateDnaSequencesAsyncTask,
             BulkCreateRnaSequencesAsyncTask,
@@ -128,6 +138,8 @@ def _parse_response(
                 AsyncTask,
                 CreateTemplateAlignmentAsyncTask,
                 CreateConsensusAlignmentAsyncTask,
+                CreateNucleotideTemplateAlignmentAsyncTask,
+                CreateNucleotideConsensusAlignmentAsyncTask,
                 BulkCreateDnaSequencesAsyncTask,
                 BulkUpdateDnaSequencesAsyncTask,
                 BulkCreateRnaSequencesAsyncTask,
@@ -174,6 +186,22 @@ def _parse_response(
                     raise TypeError()
                 response_200 = CreateConsensusAlignmentAsyncTask.from_dict(data)
 
+                return response_200
+            except:  # noqa: E722
+                pass
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200 = CreateNucleotideTemplateAlignmentAsyncTask.from_dict(data)
+
+                return response_200
+            except:  # noqa: E722
+                pass
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200 = CreateNucleotideConsensusAlignmentAsyncTask.from_dict(data)
+
                 return response_200
             except:  # noqa: E722
                 pass
@@ -381,6 +409,8 @@ def _build_response(
             AsyncTask,
             CreateTemplateAlignmentAsyncTask,
             CreateConsensusAlignmentAsyncTask,
+            CreateNucleotideTemplateAlignmentAsyncTask,
+            CreateNucleotideConsensusAlignmentAsyncTask,
             BulkCreateDnaSequencesAsyncTask,
             BulkUpdateDnaSequencesAsyncTask,
             BulkCreateRnaSequencesAsyncTask,
@@ -427,6 +457,8 @@ def sync_detailed(
             AsyncTask,
             CreateTemplateAlignmentAsyncTask,
             CreateConsensusAlignmentAsyncTask,
+            CreateNucleotideTemplateAlignmentAsyncTask,
+            CreateNucleotideConsensusAlignmentAsyncTask,
             BulkCreateDnaSequencesAsyncTask,
             BulkUpdateDnaSequencesAsyncTask,
             BulkCreateRnaSequencesAsyncTask,
@@ -477,6 +509,8 @@ def sync(
             AsyncTask,
             CreateTemplateAlignmentAsyncTask,
             CreateConsensusAlignmentAsyncTask,
+            CreateNucleotideTemplateAlignmentAsyncTask,
+            CreateNucleotideConsensusAlignmentAsyncTask,
             BulkCreateDnaSequencesAsyncTask,
             BulkUpdateDnaSequencesAsyncTask,
             BulkCreateRnaSequencesAsyncTask,
@@ -523,6 +557,8 @@ async def asyncio_detailed(
             AsyncTask,
             CreateTemplateAlignmentAsyncTask,
             CreateConsensusAlignmentAsyncTask,
+            CreateNucleotideTemplateAlignmentAsyncTask,
+            CreateNucleotideConsensusAlignmentAsyncTask,
             BulkCreateDnaSequencesAsyncTask,
             BulkUpdateDnaSequencesAsyncTask,
             BulkCreateRnaSequencesAsyncTask,
@@ -572,6 +608,8 @@ async def asyncio(
             AsyncTask,
             CreateTemplateAlignmentAsyncTask,
             CreateConsensusAlignmentAsyncTask,
+            CreateNucleotideTemplateAlignmentAsyncTask,
+            CreateNucleotideConsensusAlignmentAsyncTask,
             BulkCreateDnaSequencesAsyncTask,
             BulkUpdateDnaSequencesAsyncTask,
             BulkCreateRnaSequencesAsyncTask,
