@@ -72,7 +72,7 @@ class AaSequenceUpdate:
         schema_id = self._schema_id
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if entity_registry_id is not UNSET:
             field_dict["entityRegistryId"] = entity_registry_id
         if aliases is not UNSET:
