@@ -23,11 +23,9 @@ class AutomationOutputProcessorUpdate:
         file_id = self._file_id
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "fileId": file_id,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if file_id is not UNSET:
+            field_dict["fileId"] = file_id
 
         return field_dict
 
