@@ -32,11 +32,9 @@ class AutomationOutputProcessorsArchive:
             reason = self._reason.value
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "automationOutputProcessorIds": automation_output_processor_ids,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if automation_output_processor_ids is not UNSET:
+            field_dict["automationOutputProcessorIds"] = automation_output_processor_ids
         if reason is not UNSET:
             field_dict["reason"] = reason
 
@@ -58,7 +56,7 @@ class AutomationOutputProcessorsArchive:
         )
 
         def get_reason() -> Union[Unset, AutomationOutputProcessorsArchiveReason]:
-            reason = None
+            reason = UNSET
             _reason = d.pop("reason")
             if _reason is not None and _reason is not UNSET:
                 try:
