@@ -29,13 +29,13 @@ class BlobPartCreate:
         part_number = self._part_number
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "data64": data64,
-                "md5": md5,
-                "partNumber": part_number,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if data64 is not UNSET:
+            field_dict["data64"] = data64
+        if md5 is not UNSET:
+            field_dict["md5"] = md5
+        if part_number is not UNSET:
+            field_dict["partNumber"] = part_number
 
         return field_dict
 
