@@ -45,11 +45,9 @@ class BulkUpdateCustomEntitiesAsyncTask:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "status": status,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if status is not UNSET:
+            field_dict["status"] = status
         if response is not UNSET:
             field_dict["response"] = response
         if errors is not UNSET:
