@@ -50,7 +50,7 @@ class CheckboxNotePart:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if checked is not UNSET:
             field_dict["checked"] = checked
         if links is not UNSET:
@@ -93,7 +93,7 @@ class CheckboxNotePart:
         text = get_text() if "text" in d else cast(Union[Unset, str], UNSET)
 
         def get_type() -> Union[Unset, CheckboxNotePartType]:
-            type = None
+            type = UNSET
             _type = d.pop("type")
             if _type is not None and _type is not UNSET:
                 try:
