@@ -33,7 +33,7 @@ class ContainerSchemasList:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if container_schemas is not UNSET:
             field_dict["containerSchemas"] = container_schemas
 
