@@ -129,7 +129,7 @@ class ContainerWithCoordinates:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if grid_number is not UNSET:
             field_dict["gridNumber"] = grid_number
         if grid_position is not UNSET:
