@@ -28,11 +28,9 @@ class ContainersBulkCreateRequest:
             containers.append(containers_item)
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "containers": containers,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if containers is not UNSET:
+            field_dict["containers"] = containers
 
         return field_dict
 
