@@ -28,12 +28,11 @@ class CustomEntitiesArchive:
         reason = self._reason.value
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "customEntityIds": custom_entity_ids,
-                "reason": reason,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if custom_entity_ids is not UNSET:
+            field_dict["customEntityIds"] = custom_entity_ids
+        if reason is not UNSET:
+            field_dict["reason"] = reason
 
         return field_dict
 
