@@ -47,12 +47,11 @@ class DnaAlignmentBase:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "algorithm": algorithm,
-                "files": files,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if algorithm is not UNSET:
+            field_dict["algorithm"] = algorithm
+        if files is not UNSET:
+            field_dict["files"] = files
         if name is not UNSET:
             field_dict["name"] = name
 
