@@ -88,7 +88,7 @@ class MixtureCreate:
             units = self._units.value
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if entity_registry_id is not UNSET:
             field_dict["entityRegistryId"] = entity_registry_id
         if folder_id is not UNSET:
@@ -137,7 +137,7 @@ class MixtureCreate:
         folder_id = get_folder_id() if "folderId" in d else cast(Union[Unset, str], UNSET)
 
         def get_naming_strategy() -> Union[Unset, NamingStrategy]:
-            naming_strategy = None
+            naming_strategy = UNSET
             _naming_strategy = d.pop("namingStrategy")
             if _naming_strategy is not None and _naming_strategy is not UNSET:
                 try:
@@ -228,7 +228,7 @@ class MixtureCreate:
         schema_id = get_schema_id() if "schemaId" in d else cast(Union[Unset, str], UNSET)
 
         def get_units() -> Union[Unset, MixtureMeasurementUnits]:
-            units = None
+            units = UNSET
             _units = d.pop("units")
             if _units is not None and _units is not UNSET:
                 try:
