@@ -32,7 +32,7 @@ class PartySummary:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if handle is not UNSET:
             field_dict["handle"] = handle
         if id is not UNSET:
