@@ -33,7 +33,7 @@ class RegistrationOrigin:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if origin_entry_id is not UNSET:
             field_dict["originEntryId"] = origin_entry_id
         if registered_at is not UNSET:
