@@ -74,7 +74,7 @@ class RequestWriteBase:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if assignees is not UNSET:
             field_dict["assignees"] = assignees
         if fields is not UNSET:
