@@ -28,11 +28,9 @@ class SampleGroupsStatusUpdate:
             sample_groups.append(sample_groups_item)
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "sampleGroups": sample_groups,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if sample_groups is not UNSET:
+            field_dict["sampleGroups"] = sample_groups
 
         return field_dict
 
