@@ -28,7 +28,7 @@ class UpdateEventMixin:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if updates is not UNSET:
             field_dict["updates"] = updates
 
