@@ -32,7 +32,7 @@ class UserValidation:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if validation_comment is not UNSET:
             field_dict["validationComment"] = validation_comment
         if validation_status is not UNSET:
@@ -53,7 +53,7 @@ class UserValidation:
         )
 
         def get_validation_status() -> Union[Unset, UserValidationValidationStatus]:
-            validation_status = None
+            validation_status = UNSET
             _validation_status = d.pop("validationStatus")
             if _validation_status is not None and _validation_status is not UNSET:
                 try:
