@@ -21,6 +21,7 @@ def _get_kwargs(
     assignee_ids: Union[Unset, str] = UNSET,
     watcher_ids: Union[Unset, str] = UNSET,
     responsible_team_ids: Union[Unset, str] = UNSET,
+    responsible_party_ids: Union[Unset, str] = UNSET,
     flowchart_workflow_task_group_ids: Union[Unset, str] = UNSET,
     flowchart_task_schema_id: Union[Unset, str] = UNSET,
     flowchart_creator_ids: Union[Unset, str] = UNSET,
@@ -113,6 +114,8 @@ def _get_kwargs(
         params["watcherIds"] = watcher_ids
     if not isinstance(responsible_team_ids, Unset) and responsible_team_ids is not None:
         params["responsibleTeamIds"] = responsible_team_ids
+    if not isinstance(responsible_party_ids, Unset) and responsible_party_ids is not None:
+        params["responsiblePartyIds"] = responsible_party_ids
     if (
         not isinstance(flowchart_workflow_task_group_ids, Unset)
         and flowchart_workflow_task_group_ids is not None
@@ -211,6 +214,7 @@ def sync_detailed(
     assignee_ids: Union[Unset, str] = UNSET,
     watcher_ids: Union[Unset, str] = UNSET,
     responsible_team_ids: Union[Unset, str] = UNSET,
+    responsible_party_ids: Union[Unset, str] = UNSET,
     flowchart_workflow_task_group_ids: Union[Unset, str] = UNSET,
     flowchart_task_schema_id: Union[Unset, str] = UNSET,
     flowchart_creator_ids: Union[Unset, str] = UNSET,
@@ -250,6 +254,7 @@ def sync_detailed(
         assignee_ids=assignee_ids,
         watcher_ids=watcher_ids,
         responsible_team_ids=responsible_team_ids,
+        responsible_party_ids=responsible_party_ids,
         flowchart_workflow_task_group_ids=flowchart_workflow_task_group_ids,
         flowchart_task_schema_id=flowchart_task_schema_id,
         flowchart_creator_ids=flowchart_creator_ids,
@@ -298,6 +303,7 @@ def sync(
     assignee_ids: Union[Unset, str] = UNSET,
     watcher_ids: Union[Unset, str] = UNSET,
     responsible_team_ids: Union[Unset, str] = UNSET,
+    responsible_party_ids: Union[Unset, str] = UNSET,
     flowchart_workflow_task_group_ids: Union[Unset, str] = UNSET,
     flowchart_task_schema_id: Union[Unset, str] = UNSET,
     flowchart_creator_ids: Union[Unset, str] = UNSET,
@@ -339,6 +345,7 @@ def sync(
         assignee_ids=assignee_ids,
         watcher_ids=watcher_ids,
         responsible_team_ids=responsible_team_ids,
+        responsible_party_ids=responsible_party_ids,
         flowchart_workflow_task_group_ids=flowchart_workflow_task_group_ids,
         flowchart_task_schema_id=flowchart_task_schema_id,
         flowchart_creator_ids=flowchart_creator_ids,
@@ -381,6 +388,7 @@ async def asyncio_detailed(
     assignee_ids: Union[Unset, str] = UNSET,
     watcher_ids: Union[Unset, str] = UNSET,
     responsible_team_ids: Union[Unset, str] = UNSET,
+    responsible_party_ids: Union[Unset, str] = UNSET,
     flowchart_workflow_task_group_ids: Union[Unset, str] = UNSET,
     flowchart_task_schema_id: Union[Unset, str] = UNSET,
     flowchart_creator_ids: Union[Unset, str] = UNSET,
@@ -420,6 +428,7 @@ async def asyncio_detailed(
         assignee_ids=assignee_ids,
         watcher_ids=watcher_ids,
         responsible_team_ids=responsible_team_ids,
+        responsible_party_ids=responsible_party_ids,
         flowchart_workflow_task_group_ids=flowchart_workflow_task_group_ids,
         flowchart_task_schema_id=flowchart_task_schema_id,
         flowchart_creator_ids=flowchart_creator_ids,
@@ -467,6 +476,7 @@ async def asyncio(
     assignee_ids: Union[Unset, str] = UNSET,
     watcher_ids: Union[Unset, str] = UNSET,
     responsible_team_ids: Union[Unset, str] = UNSET,
+    responsible_party_ids: Union[Unset, str] = UNSET,
     flowchart_workflow_task_group_ids: Union[Unset, str] = UNSET,
     flowchart_task_schema_id: Union[Unset, str] = UNSET,
     flowchart_creator_ids: Union[Unset, str] = UNSET,
@@ -509,6 +519,7 @@ async def asyncio(
             assignee_ids=assignee_ids,
             watcher_ids=watcher_ids,
             responsible_team_ids=responsible_team_ids,
+            responsible_party_ids=responsible_party_ids,
             flowchart_workflow_task_group_ids=flowchart_workflow_task_group_ids,
             flowchart_task_schema_id=flowchart_task_schema_id,
             flowchart_creator_ids=flowchart_creator_ids,
