@@ -66,7 +66,7 @@ class BenchlingApp:
         name = self._name
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if api_url is not UNSET:
             field_dict["apiUrl"] = api_url
         if archive_record is not UNSET:
