@@ -108,7 +108,7 @@ class BenchlingAppManifest:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if configuration is not UNSET:
             field_dict["configuration"] = configuration
         if features is not UNSET:
@@ -255,6 +255,10 @@ class BenchlingAppManifest:
                         if discriminator_value == "mixture":
                             configuration_item = ResourceDependency.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "molecule":
+                            configuration_item = ResourceDependency.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "plate":
                             configuration_item = ResourceDependency.from_dict(data)
@@ -279,6 +283,14 @@ class BenchlingAppManifest:
                         if discriminator_value == "result_schema":
                             configuration_item = SchemaDependency.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "rna_oligo":
+                            configuration_item = ResourceDependency.from_dict(data)
+
+                            return configuration_item
+                        if discriminator_value == "rna_sequence":
+                            configuration_item = ResourceDependency.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "run_schema":
                             configuration_item = SchemaDependency.from_dict(data)
@@ -411,7 +423,7 @@ class BenchlingAppManifest:
         info = get_info() if "info" in d else cast(Union[Unset, BenchlingAppManifestInfo], UNSET)
 
         def get_manifest_version() -> Union[Unset, BenchlingAppManifestManifestVersion]:
-            manifest_version = None
+            manifest_version = UNSET
             _manifest_version = d.pop("manifestVersion")
             if _manifest_version is not None and _manifest_version is not UNSET:
                 try:
