@@ -77,7 +77,7 @@ class BenchlingAppUpdate:
                 configuration.append(configuration_item)
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if description is not UNSET:
             field_dict["description"] = description
         if name is not UNSET:
@@ -217,6 +217,10 @@ class BenchlingAppUpdate:
                         if discriminator_value == "integer":
                             configuration_item = ScalarConfig.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "json":
+                            configuration_item = ScalarConfig.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "location":
                             configuration_item = ResourceDependencyLink.from_dict(data)
@@ -229,6 +233,10 @@ class BenchlingAppUpdate:
                         if discriminator_value == "mixture":
                             configuration_item = ResourceDependencyLink.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "molecule":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "plate":
                             configuration_item = ResourceDependencyLink.from_dict(data)
@@ -253,6 +261,14 @@ class BenchlingAppUpdate:
                         if discriminator_value == "result_schema":
                             configuration_item = SchemaDependencyLink.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "rna_oligo":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
+                            return configuration_item
+                        if discriminator_value == "rna_sequence":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "run_schema":
                             configuration_item = SchemaDependencyLink.from_dict(data)
