@@ -29,7 +29,7 @@ class EntryAttachments:
             attachments = self._attachments
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if attachment_text is not UNSET:
             field_dict["attachmentText"] = attachment_text
         if attachments is not UNSET:
