@@ -101,7 +101,7 @@ class WorkflowOutput:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if next_outputs is not UNSET:
             field_dict["nextOutputs"] = next_outputs
         if next_tasks is not UNSET:
