@@ -7,6 +7,7 @@ from dateutil.parser import isoparse
 from ..extensions import NotPresentError
 from ..models.creation_origin import CreationOrigin
 from ..models.fields import Fields
+from ..models.party_summary import PartySummary
 from ..models.user_summary import UserSummary
 from ..models.workflow_output_summary import WorkflowOutputSummary
 from ..models.workflow_task_execution_origin import WorkflowTaskExecutionOrigin
@@ -27,6 +28,7 @@ class WorkflowTask:
     _execution_type: Union[Unset, WorkflowTaskExecutionType] = UNSET
     _next_outputs: Union[Unset, List[WorkflowOutputSummary]] = UNSET
     _next_tasks: Union[Unset, List[WorkflowTaskSummary]] = UNSET
+    _responsible_parties: Union[Unset, List[PartySummary]] = UNSET
     _root_task: Union[Unset, WorkflowTaskSummary] = UNSET
     _source_outputs: Union[Unset, List[WorkflowOutputSummary]] = UNSET
     _source_tasks: Union[Unset, List[WorkflowTaskSummary]] = UNSET
@@ -51,6 +53,7 @@ class WorkflowTask:
         fields.append("execution_type={}".format(repr(self._execution_type)))
         fields.append("next_outputs={}".format(repr(self._next_outputs)))
         fields.append("next_tasks={}".format(repr(self._next_tasks)))
+        fields.append("responsible_parties={}".format(repr(self._responsible_parties)))
         fields.append("root_task={}".format(repr(self._root_task)))
         fields.append("source_outputs={}".format(repr(self._source_outputs)))
         fields.append("source_tasks={}".format(repr(self._source_tasks)))
@@ -92,6 +95,14 @@ class WorkflowTask:
 
                 next_tasks.append(next_tasks_item)
 
+        responsible_parties: Union[Unset, List[Any]] = UNSET
+        if not isinstance(self._responsible_parties, Unset):
+            responsible_parties = []
+            for responsible_parties_item_data in self._responsible_parties:
+                responsible_parties_item = responsible_parties_item_data.to_dict()
+
+                responsible_parties.append(responsible_parties_item)
+
         root_task: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self._root_task, Unset):
             root_task = self._root_task.to_dict()
@@ -162,7 +173,7 @@ class WorkflowTask:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if execution_flowchart_id is not UNSET:
             field_dict["executionFlowchartId"] = execution_flowchart_id
         if execution_type is not UNSET:
@@ -171,6 +182,8 @@ class WorkflowTask:
             field_dict["nextOutputs"] = next_outputs
         if next_tasks is not UNSET:
             field_dict["nextTasks"] = next_tasks
+        if responsible_parties is not UNSET:
+            field_dict["responsibleParties"] = responsible_parties
         if root_task is not UNSET:
             field_dict["rootTask"] = root_task
         if source_outputs is not UNSET:
@@ -219,7 +232,7 @@ class WorkflowTask:
         )
 
         def get_execution_type() -> Union[Unset, WorkflowTaskExecutionType]:
-            execution_type = None
+            execution_type = UNSET
             _execution_type = d.pop("executionType")
             if _execution_type is not None and _execution_type is not UNSET:
                 try:
@@ -265,6 +278,22 @@ class WorkflowTask:
             get_next_tasks() if "nextTasks" in d else cast(Union[Unset, List[WorkflowTaskSummary]], UNSET)
         )
 
+        def get_responsible_parties() -> Union[Unset, List[PartySummary]]:
+            responsible_parties = []
+            _responsible_parties = d.pop("responsibleParties")
+            for responsible_parties_item_data in _responsible_parties or []:
+                responsible_parties_item = PartySummary.from_dict(responsible_parties_item_data)
+
+                responsible_parties.append(responsible_parties_item)
+
+            return responsible_parties
+
+        responsible_parties = (
+            get_responsible_parties()
+            if "responsibleParties" in d
+            else cast(Union[Unset, List[PartySummary]], UNSET)
+        )
+
         def get_root_task() -> Union[Unset, WorkflowTaskSummary]:
             root_task: Union[Unset, WorkflowTaskSummary] = UNSET
             _root_task = d.pop("rootTask")
@@ -444,6 +473,7 @@ class WorkflowTask:
             execution_type=execution_type,
             next_outputs=next_outputs,
             next_tasks=next_tasks,
+            responsible_parties=responsible_parties,
             root_task=root_task,
             source_outputs=source_outputs,
             source_tasks=source_tasks,
@@ -542,6 +572,21 @@ class WorkflowTask:
     def next_tasks(self) -> None:
         self._next_tasks = UNSET
 
+    @property
+    def responsible_parties(self) -> List[PartySummary]:
+        """ List of users and teams that are responsible for this task """
+        if isinstance(self._responsible_parties, Unset):
+            raise NotPresentError(self, "responsible_parties")
+        return self._responsible_parties
+
+    @responsible_parties.setter
+    def responsible_parties(self, value: List[PartySummary]) -> None:
+        self._responsible_parties = value
+
+    @responsible_parties.deleter
+    def responsible_parties(self) -> None:
+        self._responsible_parties = UNSET
+
     @property
     def root_task(self) -> WorkflowTaskSummary:
         if isinstance(self._root_task, Unset):
