@@ -137,7 +137,7 @@ class WorkflowTaskGroup:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if execution_type is not UNSET:
             field_dict["executionType"] = execution_type
         if flowchart_config_version_id is not UNSET:
@@ -180,7 +180,7 @@ class WorkflowTaskGroup:
         d = src_dict.copy()
 
         def get_execution_type() -> Union[Unset, WorkflowTaskGroupExecutionType]:
-            execution_type = None
+            execution_type = UNSET
             _execution_type = d.pop("executionType")
             if _execution_type is not None and _execution_type is not UNSET:
                 try:
