@@ -7,6 +7,7 @@ from ..models.archive_record import ArchiveRecord
 from ..models.dropdown_field_definition import DropdownFieldDefinition
 from ..models.float_field_definition import FloatFieldDefinition
 from ..models.integer_field_definition import IntegerFieldDefinition
+from ..models.party_summary import PartySummary
 from ..models.schema_link_field_definition import SchemaLinkFieldDefinition
 from ..models.simple_field_definition import SimpleFieldDefinition
 from ..models.team_summary import TeamSummary
@@ -23,6 +24,7 @@ T = TypeVar("T", bound="WorkflowTaskSchema")
 class WorkflowTaskSchema:
     """  """
 
+    _default_responsible_parties: Union[Unset, List[PartySummary]] = UNSET
     _execution_type: Union[Unset, WorkflowTaskSchemaExecutionType] = UNSET
     _flowchart_config: Union[Unset, WorkflowFlowchartConfigSummary] = UNSET
     _template_flowchart_id: Union[Unset, str] = UNSET
@@ -56,6 +58,7 @@ class WorkflowTaskSchema:
 
     def __repr__(self):
         fields = []
+        fields.append("default_responsible_parties={}".format(repr(self._default_responsible_parties)))
         fields.append("execution_type={}".format(repr(self._execution_type)))
         fields.append("flowchart_config={}".format(repr(self._flowchart_config)))
         fields.append("template_flowchart_id={}".format(repr(self._template_flowchart_id)))
@@ -81,6 +84,14 @@ class WorkflowTaskSchema:
         return "WorkflowTaskSchema({})".format(", ".join(fields))
 
     def to_dict(self) -> Dict[str, Any]:
+        default_responsible_parties: Union[Unset, List[Any]] = UNSET
+        if not isinstance(self._default_responsible_parties, Unset):
+            default_responsible_parties = []
+            for default_responsible_parties_item_data in self._default_responsible_parties:
+                default_responsible_parties_item = default_responsible_parties_item_data.to_dict()
+
+                default_responsible_parties.append(default_responsible_parties_item)
+
         execution_type: Union[Unset, int] = UNSET
         if not isinstance(self._execution_type, Unset):
             execution_type = self._execution_type.value
@@ -145,7 +156,9 @@ class WorkflowTaskSchema:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if default_responsible_parties is not UNSET:
+            field_dict["defaultResponsibleParties"] = default_responsible_parties
         if execution_type is not UNSET:
             field_dict["executionType"] = execution_type
         if flowchart_config is not UNSET:
@@ -187,8 +200,26 @@ class WorkflowTaskSchema:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
 
+        def get_default_responsible_parties() -> Union[Unset, List[PartySummary]]:
+            default_responsible_parties = []
+            _default_responsible_parties = d.pop("defaultResponsibleParties")
+            for default_responsible_parties_item_data in _default_responsible_parties or []:
+                default_responsible_parties_item = PartySummary.from_dict(
+                    default_responsible_parties_item_data
+                )
+
+                default_responsible_parties.append(default_responsible_parties_item)
+
+            return default_responsible_parties
+
+        default_responsible_parties = (
+            get_default_responsible_parties()
+            if "defaultResponsibleParties" in d
+            else cast(Union[Unset, List[PartySummary]], UNSET)
+        )
+
         def get_execution_type() -> Union[Unset, WorkflowTaskSchemaExecutionType]:
-            execution_type = None
+            execution_type = UNSET
             _execution_type = d.pop("executionType")
             if _execution_type is not None and _execution_type is not UNSET:
                 try:
@@ -455,6 +486,7 @@ class WorkflowTaskSchema:
         type = get_type() if "type" in d else cast(Union[Unset, str], UNSET)
 
         workflow_task_schema = cls(
+            default_responsible_parties=default_responsible_parties,
             execution_type=execution_type,
             flowchart_config=flowchart_config,
             template_flowchart_id=template_flowchart_id,
@@ -496,6 +528,21 @@ class WorkflowTaskSchema:
     def get(self, key, default=None) -> Optional[Any]:
         return self.additional_properties.get(key, default)
 
+    @property
+    def default_responsible_parties(self) -> List[PartySummary]:
+        """ Default list of users and teams that are responsible for tasks of this schema """
+        if isinstance(self._default_responsible_parties, Unset):
+            raise NotPresentError(self, "default_responsible_parties")
+        return self._default_responsible_parties
+
+    @default_responsible_parties.setter
+    def default_responsible_parties(self, value: List[PartySummary]) -> None:
+        self._default_responsible_parties = value
+
+    @default_responsible_parties.deleter
+    def default_responsible_parties(self) -> None:
+        self._default_responsible_parties = UNSET
+
     @property
     def execution_type(self) -> WorkflowTaskSchemaExecutionType:
         """ The method by which instances of this schema are executed """
