@@ -74,7 +74,7 @@ class BenchlingAppConfigList:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if configuration is not UNSET:
             field_dict["configuration"] = configuration
 
@@ -198,6 +198,10 @@ class BenchlingAppConfigList:
                         if discriminator_value == "integer":
                             configuration_item = ScalarConfig.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "json":
+                            configuration_item = ScalarConfig.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "location":
                             configuration_item = ResourceDependencyLink.from_dict(data)
@@ -210,6 +214,10 @@ class BenchlingAppConfigList:
                         if discriminator_value == "mixture":
                             configuration_item = ResourceDependencyLink.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "molecule":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "plate":
                             configuration_item = ResourceDependencyLink.from_dict(data)
@@ -234,6 +242,14 @@ class BenchlingAppConfigList:
                         if discriminator_value == "result_schema":
                             configuration_item = SchemaDependencyLink.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "rna_oligo":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
+                            return configuration_item
+                        if discriminator_value == "rna_sequence":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "run_schema":
                             configuration_item = SchemaDependencyLink.from_dict(data)
