@@ -83,7 +83,7 @@ class BenchlingAppConfiguration:
                 configuration.append(configuration_item)
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if api_url is not UNSET:
             field_dict["apiUrl"] = api_url
         if app_id is not UNSET:
@@ -239,6 +239,10 @@ class BenchlingAppConfiguration:
                         if discriminator_value == "integer":
                             configuration_item = ScalarConfig.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "json":
+                            configuration_item = ScalarConfig.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "location":
                             configuration_item = ResourceDependencyLink.from_dict(data)
@@ -251,6 +255,10 @@ class BenchlingAppConfiguration:
                         if discriminator_value == "mixture":
                             configuration_item = ResourceDependencyLink.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "molecule":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "plate":
                             configuration_item = ResourceDependencyLink.from_dict(data)
@@ -275,6 +283,14 @@ class BenchlingAppConfiguration:
                         if discriminator_value == "result_schema":
                             configuration_item = SchemaDependencyLink.from_dict(data)
 
+                            return configuration_item
+                        if discriminator_value == "rna_oligo":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
+                            return configuration_item
+                        if discriminator_value == "rna_sequence":
+                            configuration_item = ResourceDependencyLink.from_dict(data)
+
                             return configuration_item
                         if discriminator_value == "run_schema":
                             configuration_item = SchemaDependencyLink.from_dict(data)
