@@ -117,7 +117,7 @@ class CustomEntity:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if aliases is not UNSET:
             field_dict["aliases"] = aliases
         if api_url is not UNSET:
