@@ -109,13 +109,13 @@ class DnaSequenceBulkUpsertRequest:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "name": name,
-                "schemaId": schema_id,
-                "registryId": registry_id,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if name is not UNSET:
+            field_dict["name"] = name
+        if schema_id is not UNSET:
+            field_dict["schemaId"] = schema_id
+        if registry_id is not UNSET:
+            field_dict["registryId"] = registry_id
         if aliases is not UNSET:
             field_dict["aliases"] = aliases
         if annotations is not UNSET:
