@@ -72,12 +72,11 @@ class EntryCreate:
         schema_id = self._schema_id
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "folderId": folder_id,
-                "name": name,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if folder_id is not UNSET:
+            field_dict["folderId"] = folder_id
+        if name is not UNSET:
+            field_dict["name"] = name
         if author_ids is not UNSET:
             field_dict["authorIds"] = author_ids
         if custom_fields is not UNSET:
