@@ -104,7 +104,7 @@ class BoxSchema:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if container_schema is not UNSET:
             field_dict["containerSchema"] = container_schema
         if height is not UNSET:
@@ -153,7 +153,7 @@ class BoxSchema:
         height = get_height() if "height" in d else cast(Union[Unset, float], UNSET)
 
         def get_type() -> Union[Unset, BoxSchemaType]:
-            type = None
+            type = UNSET
             _type = d.pop("type")
             if _type is not None and _type is not UNSET:
                 try:
