@@ -109,7 +109,7 @@ class DnaSequenceBulkCreate:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if entity_registry_id is not UNSET:
             field_dict["entityRegistryId"] = entity_registry_id
         if folder_id is not UNSET:
@@ -162,7 +162,7 @@ class DnaSequenceBulkCreate:
         folder_id = get_folder_id() if "folderId" in d else cast(Union[Unset, str], UNSET)
 
         def get_naming_strategy() -> Union[Unset, NamingStrategy]:
-            naming_strategy = None
+            naming_strategy = UNSET
             _naming_strategy = d.pop("namingStrategy")
             if _naming_strategy is not None and _naming_strategy is not UNSET:
                 try:
