@@ -68,7 +68,7 @@ class FeatureLibrary:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if created_at is not UNSET:
             field_dict["createdAt"] = created_at
         if id is not UNSET:
