@@ -126,7 +126,7 @@ class RnaOligoWithEntityType:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if entity_type is not UNSET:
             field_dict["entityType"] = entity_type
         if api_url is not UNSET:
@@ -175,7 +175,7 @@ class RnaOligoWithEntityType:
         d = src_dict.copy()
 
         def get_entity_type() -> Union[Unset, RnaOligoWithEntityTypeEntityType]:
-            entity_type = None
+            entity_type = UNSET
             _entity_type = d.pop("entityType")
             if _entity_type is not None and _entity_type is not UNSET:
                 try:
@@ -204,7 +204,7 @@ class RnaOligoWithEntityType:
         bases = get_bases() if "bases" in d else cast(Union[Unset, str], UNSET)
 
         def get_nucleotide_type() -> Union[Unset, OligoNucleotideType]:
-            nucleotide_type = None
+            nucleotide_type = UNSET
             _nucleotide_type = d.pop("nucleotideType")
             if _nucleotide_type is not None and _nucleotide_type is not UNSET:
                 try:
