@@ -1,4 +1,6 @@
 """Contains some shared types for properties."""
+from __future__ import annotations
+
 from typing import BinaryIO, Generic, MutableMapping, Optional, TextIO, Tuple, TypeVar, Union
 
 import attr
@@ -8,6 +10,12 @@ class Unset:
     def __bool__(self) -> bool:
         return False
 
+    def __copy__(self) -> Unset:
+        return UNSET
+
+    def __deepcopy__(self, memo) -> Unset:
+        return UNSET
+
 
 UNSET: Unset = Unset()
 
